@@ -7,6 +7,8 @@ from typing import Iterator, List, Tuple
 
 from django.core.files.storage import Storage
 
+from s3_file_field._sizes import gb, mb, tb
+
 
 @dataclass
 class PresignedPartTransfer:
@@ -57,9 +59,9 @@ class ObjectNotFoundException(Exception):
 class MultipartManager:
     """A facade providing management of S3 multipart uploads to multiple Storages."""
 
-    def initialize_upload(
-        self, object_key: str, file_size: int, part_size: int = None
-    ) -> PresignedTransfer:
+    part_size = mb(64)
+
+    def initialize_upload(self, object_key: str, file_size: int) -> PresignedTransfer:
         upload_id = self._create_upload_id(object_key)
         parts = [
             PresignedPartTransfer(
@@ -69,7 +71,7 @@ class MultipartManager:
                     object_key, upload_id, part_number, part_size
                 ),
             )
-            for part_number, part_size in self._iter_part_sizes(file_size, part_size)
+            for part_number, part_size in self._iter_part_sizes(file_size)
         ]
         return PresignedTransfer(object_key=object_key, upload_id=upload_id, parts=parts)
 
@@ -158,30 +160,27 @@ class MultipartManager:
     def get_object_size(self, object_key: str) -> int:
         raise NotImplementedError
 
-    @staticmethod
-    def _iter_part_sizes(file_size: int, part_size: int = None) -> Iterator[Tuple[int, int]]:
-        if part_size is None:
-            # 5 MB
-            # TODO: pick a sane default; 1GB?
-            part_size = 5 * 2 ** 20
+    @classmethod
+    def _iter_part_sizes(cls, file_size: int) -> Iterator[Tuple[int, int]]:
+        part_size = cls.part_size
 
         # S3 multipart limits: https://docs.aws.amazon.com/AmazonS3/latest/dev/qfacts.html
 
-        if file_size > 5 * 2 ** 40:
+        if file_size > tb(5):
             raise Exception('File is larger than the S3 maximum object size.')
 
-        # 10k is the maximum number of allowed parts
+        # 10k is the maximum number of allowed parts allowed by S3
         max_parts = 10_000
         if math.ceil(file_size / part_size) >= max_parts:
             part_size = math.ceil(file_size / max_parts)
 
-        # 5MB is the minimum part size
-        min_part_size = 5 * 2 ** 20
+        # 5MB is the minimum part size allowed by S3
+        min_part_size = mb(5)
         if part_size < min_part_size:
             part_size = min_part_size
 
-        # 5GB is the maximum part size
-        max_part_size = 5 * 2 ** 30
+        # 5GB is the maximum part size allowed by S3
+        max_part_size = gb(5)
         if part_size > max_part_size:
             part_size = max_part_size
 
